@@ -1,3 +1,32 @@
+#' Import 3D surface mesh files
+#' 
+#' imports 3D mesh files and store them as an R .object of class mesh3d
+#' 
+#'  
+#' @title Import 3D surface mesh files
+#' @param filename character: path to file
+#' @param adnormals Logical: If the file does not contain normal information,
+#' they will be calculated in R: Can take some time.
+#' @param readnormals Logical: Import vertex normals (if available), although
+#' no face information is present.
+#' @param readcol Logical: Import vertex colors (if available).
+#' @param clean Logical: Delete dumpfiles.
+#' @param silent logical: suppress messages.
+#' @return
+#' \item{mesh }{list of class mesh3d - see rgl manual for further details,
+#' or a matrix containing vertex information or a list containing vertex and
+#' normal information}
+#' @keywords ~kwd1 ~kwd2
+#' @examples
+#' 
+#' data(nose)
+#' mesh2ply(shortnose.mesh)
+#' mesh <- ply2mesh("shortnose.mesh.ply")
+#' 
+#' mesh2obj(shortnose.mesh)
+#' mesh2 <- obj2mesh("shortnose.mesh.obj")
+#' @rdname ply2mesh
+#' @export
 ply2mesh <- function (filename, adnormals = TRUE,readnormals=FALSE,readcol=FALSE, silent=FALSE)
 {
     x <- filename
@@ -94,7 +123,7 @@ ply2mesh <- function (filename, adnormals = TRUE,readnormals=FALSE,readcol=FALSE
             if (is.null(mesh$normals)) {
                 if (!silent)
                     cat("calculating normals...\n")
-                mesh <- adnormals(mesh)
+                mesh <- updateNormals(mesh)
             }
         }
     }
